#
#  SetEPGPath E2
#
#  Coded by weazle (c) 2010
#  Support: www.dreambox-tools.info
#
#  This plugin is licensed under the Creative Commons 
#  Attribution-NonCommercial-ShareAlike 3.0 Unported 
#  License. To view a copy of this license, visit
#  http://creativecommons.org/licenses/by-nc-sa/3.0/ or send a letter to Creative
#  Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.
#
#  Alternatively, this plugin may be distributed and executed on hardware which
#  is licensed by Dream Multimedia GmbH.

#  This plugin is NOT free software. It is open source, you are allowed to
#  modify it (if you keep the license), but it may not be commercially 
#  distributed other than under the conditions noted above.
#

from Plugins.Plugin import PluginDescriptor
from Screens.Screen import Screen
from Components.ActionMap import ActionMap
from Components.Sources.StaticText import StaticText
from Components.config import config, ConfigSelection, getConfigListEntry, NoSave, ConfigText, ConfigDirectory
from Components.ConfigList import ConfigListScreen
from enigma import eEPGCache
from os import path as os_path
from Components.FileList import FileList
from Components.Label import Label
from Screens.MessageBox import MessageBox

# for localized messages
from . import _

class SetEPGPath(Screen, ConfigListScreen):

	skin = """
		<screen position="center,center" size="560,320">
			<ePixmap pixmap="skin_default/buttons/red.png" position="0,0" zPosition="0" size="140,40" transparent="1" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/green.png" position="140,0" zPosition="0" size="140,40" transparent="1" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/yellow.png" position="280,0" zPosition="0" size="140,40" transparent="1" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/blue.png" position="420,0" zPosition="0" size="140,40" transparent="1" alphatest="on" />
			<widget render="Label" source="key_red" position="0,0" size="140,40" zPosition="5" valign="center" halign="center" backgroundColor="red" font="Regular;21" transparent="1" foregroundColor="white" shadowColor="black" shadowOffset="-1,-1" />
			<widget render="Label" source="key_green" position="140,0" size="140,40" zPosition="5" valign="center" halign="center" backgroundColor="red" font="Regular;21" transparent="1" foregroundColor="white" shadowColor="black" shadowOffset="-1,-1" />
			<widget name="config" position="20,50" size="520,250" scrollbarMode="showOnDemand" />
		</screen>"""

	def __init__(self, session):
		self.session = session
		Screen.__init__(self, session)
		self["key_red"] = StaticText(_("Cancel"))
		self["key_green"] = StaticText(_("Save"))
		path,filename = os_path.split(config.misc.epgcache_filename.value)
		#self.epgcache_path = NoSave(ConfigSelection(choices = [("/hdd", "/hdd"), ("/media/cf", "/media/cf"), ("/media/usb", "/media/usb")], default = path))
		self.epgcache_path = NoSave(ConfigDirectory(default = path))
		self.epgcache_filename = NoSave(ConfigText(default = filename, visible_width = 50, fixed_size = False))
		list = []
		list.append(getConfigListEntry(_("EPG path"), self.epgcache_path))
		list.append(getConfigListEntry(_("EPG file name"), self.epgcache_filename))		
		ConfigListScreen.__init__(self, list)
		self["setupActions"] = ActionMap(["SetupActions", "ColorActions"],
		{
			#"ok": self.save,
			"ok": self.keySelect,
			"green": self.save,
			"red": self.exit,
			"cancel": self.exit,
		}, -1)
		self.onLayoutFinish.append(self.setCustomTitle)

	def setCustomTitle(self):
		self.setTitle(_("Set EPG path"))

	def save(self):
		config.misc.epgcache_filename.value = os_path.join(self.epgcache_path.value, self.epgcache_filename.value)
		config.misc.epgcache_filename.save()
		config.misc.epgcache_filename.changed()
		self.session.open(MessageBox, _("EPG path changed to: \'%s\'") % config.misc.epgcache_filename.value, type = MessageBox.TYPE_INFO,timeout = 5)
		try:
			savetype = int(config.plugins.automaticepgcachesave.type.value)
			if savetype > 0:
				print "[AutomaticEPGCacheSave] saving epg.dat..."
				epgcache = eEPGCache.getInstance()
				epgcache.save() # Merlin2 feature only
			else:
				print "[AutomaticEPGCacheSave] disabled..."
		except:
			print "[SetEPGPath] AutomaticEPGCacheSave not installed..."
		self.close()

	def exit(self):
		self.close()
	
	def keySelect(self):
		self.session.openWithCallback(self.pathSelected,epgPath,self.epgcache_path.value)

	def pathSelected(self, res):
		if res is not None:
			self.epgcache_path.value = res

class epgPath(Screen):
	skin = """<screen position="center,center" size="560,320">
			<ePixmap pixmap="skin_default/buttons/red.png" position="0,0" zPosition="0" size="140,40" transparent="1" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/green.png" position="140,0" zPosition="0" size="140,40" transparent="1" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/yellow.png" position="280,0" zPosition="0" size="140,40" transparent="1" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/blue.png" position="420,0" zPosition="0" size="140,40" transparent="1" alphatest="on" />
			<widget name="target" position="0,60" size="540,22" valign="center" font="Regular;22" />
			<widget name="filelist" position="0,100" zPosition="1" size="560,220" scrollbarMode="showOnDemand"/>
			<widget render="Label" source="key_red" position="0,0" size="140,40" zPosition="5" valign="center" halign="center" backgroundColor="red" font="Regular;21" transparent="1" foregroundColor="white" shadowColor="black" shadowOffset="-1,-1" />
			<widget render="Label" source="key_green" position="140,0" size="140,40" zPosition="5" valign="center" halign="center" backgroundColor="red" font="Regular;21" transparent="1" foregroundColor="white" shadowColor="black" shadowOffset="-1,-1" />
		</screen>"""
	def __init__(self, session, initDir):
		Screen.__init__(self, session)
		inhibitDirs = ["/bin", "/boot", "/dev", "/etc", "/lib", "/proc", "/sbin", "/sys", "/usr", "/var"]
		inhibitMounts = []
		self["filelist"] = FileList(initDir, showDirectories = True, showFiles = False, inhibitMounts = inhibitMounts, inhibitDirs = inhibitDirs)
		self["target"] = Label()
		self["actions"] = ActionMap(["WizardActions", "DirectionActions", "ColorActions", "EPGSelectActions"],
		{
			"back": self.cancel,
			"left": self.left,
			"right": self.right,
			"up": self.up,
			"down": self.down,
			"ok": self.ok,
			"green": self.green,
			"red": self.cancel
			
		}, -1)
		self["key_red"] = StaticText(_("Cancel"))
		self["key_green"] = StaticText(_("OK"))
		self.onLayoutFinish.append(self.setCustomTitle)

	def setCustomTitle(self):
		self.setTitle(_("Select path for EPG"))

	def cancel(self):
		self.close(None)

	def green(self):
		self.close(self["filelist"].getSelection()[0])

	def up(self):
		self["filelist"].up()
		self.updateTarget()

	def down(self):
		self["filelist"].down()
		self.updateTarget()

	def left(self):
		self["filelist"].pageUp()
		self.updateTarget()

	def right(self):
		self["filelist"].pageDown()
		self.updateTarget()

	def ok(self):
		if self["filelist"].canDescent():
			self["filelist"].descent()
			self.updateTarget()

	def updateTarget(self):
		currFolder = self["filelist"].getSelection()[0]
		if currFolder is not None:
			self["target"].setText(currFolder)
		else:
			self["target"].setText(_("Invalid Location"))		
			
def openEpgPath(session, **kwargs):
	session.open(SetEPGPath)

def startEpgPath(menuid):
	if menuid != "merlin":
		return [ ]
	return [(_("EPG Path"), openEpgPath, "EPGPath", None)]

def Plugins(**kwargs):
	return [PluginDescriptor(name="EPG Path", where=PluginDescriptor.WHERE_MENU, fnc=startEpgPath)]
